Who we are
==========

The Hackerfleet is a research & development venture founded by some friends who decided to
revolutionize the maritime technology sector.

We develop opensource hardware and software for unmanned and manned vessels on all
waters, we do this publicly and transparent, our repositorys are open for you.
